@@ -320,7 +320,7 @@ class RunChecks:
     def run_healthcheck(self):
         framework = object()
         plugins = []
-        output = constants.DEFAULT_OUTPUT
+        output = None
 
         logger.setLevel(logging.WARNING)
 
@@ -346,12 +346,6 @@ class RunChecks:
         if rval is not None:
             return rval
 
-        if options.verbose:
-            logger.setLevel(logging.INFO)
-
-        if options.debug:
-            logger.setLevel(logging.DEBUG)
-
         if options.config is not None:
             config = read_config(options.config)
         else:
@@ -366,19 +360,35 @@ class RunChecks:
         self.options = config
         options = config
 
+        if options.verbose:
+            logger.setLevel(logging.INFO)
+
+        if options.debug:
+            logger.setLevel(logging.DEBUG)
+
         # pylint: disable=assignment-from-none
         rval = self.pre_check()
         # pylint: enable=assignment-from-none
         if rval is not None:
             return rval
 
+        # The pki checks are noisy if a CA is not configured so we
+        # want to suppress that for IPA.
+        #
+        # There are 3 possible states:
+        # 1. IPA is configured with a CA
+        # 2. IPA is configured without a CA
+        # 3. IPA is not configured
+        #
         # If we have IPA configured without a CA then we want to skip
-        # the pkihealthcheck plugins otherwise they will generated a
-        # lot of false positives. The IPA plugins are loaded first so
-        # which should set ca_configured in its registry to True or
-        # False. We will skip the pkihealthcheck plugins only if
-        # ca_configured is False which means that it was set by IPA.
-        ca_configured = False
+        # the pkihealthcheck plugins
+        #
+        # The IPA registry will set ca_configured in its registry to True
+        # or False. We will skip the pkihealthcheck plugins only if
+        # ca_configured is False which means that it was set by IPA. So
+        # we initialize ca_configured to None so that the pki checks
+        # will always be executed with pki-healthcheck.
+        ca_configured = None
         for name, registry in find_registries(self.entry_points).items():
             try:
                 registry.initialize(framework, config, options)
@@ -403,6 +413,9 @@ class RunChecks:
             if out.__name__.lower() == options.output_type:
                 output = out(options)
                 break
+        if output is None:
+            print(f"Unknown output-type '{options.output_type}'")
+            return 1
 
         if options.list_sources:
             return list_sources(plugins)
@@ -426,7 +439,7 @@ class RunChecks:
                                                      options.check)
             results.extend(run_plugins(plugins, available,
                                        options.source, options.check, config,
-                                       int(config.timeout)))
+                                       config.timeout))
 
         if options.source and len(results.results) == 0:
             for plugin in plugins:
